import { Component, HostBinding, Input, NgModule } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';
import { icon, parse } from '@fortawesome/fontawesome';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @param {?} i
 * @return {?}
 */
function isIconLookup(i) {
    return (/** @type {?} */ (i)).prefix !== undefined && (/** @type {?} */ (i)).iconName !== undefined;
}
/**
 * @param {?} iconSpec
 * @return {?}
 */
function normalizeIconArgs(iconSpec) {
    if (typeof iconSpec === 'undefined' || iconSpec === null) {
        return null;
    }
    if (isIconLookup(iconSpec)) {
        return iconSpec;
    }
    if (Array.isArray(iconSpec) && (/** @type {?} */ (iconSpec)).length === 2) {
        return { prefix: iconSpec[0], iconName: iconSpec[1] };
    }
    if (typeof iconSpec === 'string') {
        return { prefix: 'fas', iconName: iconSpec };
    }
}
/**
 * @param {?} key
 * @param {?} value
 * @return {?}
 */
function objectWithKey(key, value) {
    return ((Array.isArray(value) && value.length > 0) || (!Array.isArray(value) && value)) ? { [key]: value } : {};
}
/**
 * @record
 */

/**
 * @param {?} props
 * @return {?}
 */
function classList(props) {
    const /** @type {?} */ classes = {
        'fa-spin': props.spin,
        'fa-pulse': props.pulse,
        'fa-fw': props.fixedWidth,
        'fa-border': props.border,
        'fa-li': props.listItem,
        'fa-flip-horizontal': props.flip === 'horizontal' || props.flip === 'both',
        'fa-flip-vertical': props.flip === 'vertical' || props.flip === 'both',
        [`fa-${props.size}`]: props.size !== null,
        [`fa-rotate-${props.rotate}`]: props.rotate !== null,
        [`fa-pull-${props.pull}`]: props.pull !== null
    };
    return Object.keys(classes)
        .map(key => classes[key] ? key : null)
        .filter(key => key);
}
class FaIconComponent {
    /**
     * @param {?} sanitizer
     */
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        const /** @type {?} */ iconSpec = normalizeIconArgs(this.icon);
        const /** @type {?} */ classOpts = {
            icon: null,
            spin: this.spin,
            pulse: this.pulse,
            fixedWidth: this.fixedWidth,
            border: this.border,
            listItem: this.listItem,
            flip: this.flip,
            size: this.size || null,
            rotate: this.rotate || null,
            pull: this.pull || null
        };
        const /** @type {?} */ classes = objectWithKey('classes', [...classList(classOpts), ...(this.className || '').split(' ')]);
        const /** @type {?} */ transform = objectWithKey('transform', (typeof this.transform === 'string') ?
            parse.transform(this.transform) : this.transform);
        const /** @type {?} */ mask = objectWithKey('mask', normalizeIconArgs(this.mask));
        const /** @type {?} */ renderedIcon = icon(iconSpec, Object.assign({}, classes, transform, mask, { symbol: this.symbol }));
        // @TODO: make sure that it doesn't break things to do html[0] here.
        this.renderedIconHTML = this.sanitizer.bypassSecurityTrustHtml(renderedIcon.html[0]);
    }
}
FaIconComponent.decorators = [
    { type: Component, args: [{
                selector: 'fa-icon',
                template: ``
            },] },
];
/** @nocollapse */
FaIconComponent.ctorParameters = () => [
    { type: DomSanitizer, },
];
FaIconComponent.propDecorators = {
    "icon": [{ type: Input },],
    "mask": [{ type: Input },],
    "symbol": [{ type: Input },],
    "className": [{ type: Input },],
    "fixedWidth": [{ type: Input },],
    "spin": [{ type: Input },],
    "pulse": [{ type: Input },],
    "border": [{ type: Input },],
    "listItem": [{ type: Input },],
    "flip": [{ type: Input },],
    "size": [{ type: Input },],
    "rotate": [{ type: Input },],
    "pull": [{ type: Input },],
    "transform": [{ type: Input },],
    "renderedIconHTML": [{ type: HostBinding, args: ['innerHTML',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FontAwesomeModule {
}
FontAwesomeModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    FaIconComponent,
                ],
                exports: [
                    FaIconComponent,
                ],
            },] },
];
/** @nocollapse */
FontAwesomeModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { FaIconComponent, FontAwesomeModule };
//# sourceMappingURL=angular-fontawesome.js.map
